<template>
    <div>
        <transition name="overlay-fade">
            <div v-if="isSideCartOpen" class="overlay" @click="closeSideCart"></div>
        </transition>
        <transition name="slide">
            <div v-if="isSideCartOpen" class="side-cart">
                <div class="">
                    <div style="color: #000; background-color: #fff; border-bottom: 2px solid #eee">
                        <div class="product-row d-flex flex-wrap align-items-center justify-content-between">
                            <h2 class="side-cart-title">{{ $t("cart.yourcart") }}</h2>
                            <a class="side-cart-close-side" @click="closeSideCart">X</a>
                        </div>
                    </div>

                    <div v-for="(item, index) in products" :key="index">
                        <side-cart-product-item :product="item" />
                    </div>
                    <h3>Subtotal: ${{ formatCurrency(subtotal) }}</h3>
                </div>
                <div class="text-center">
                    <a class="just-button just-button-side-cart" @click="endBuy()"> FINALIZAR COMPRA </a>
                </div>
            </div>
        </transition>
    </div>
</template>

<script setup>
import { cartStore } from "../../js/stores/cart.js";
import { computed } from "vue";
import SideCartProductItem from "./SideCartProductItem.vue";

const props = defineProps({
    product: Object,
});

const store = cartStore();
const products = computed(() => store.items);
const subtotal = computed(() => store.subtotal);
const isSideCartOpen = computed(() => store.isSideCartOpen);

function closeSideCart() {
    store.toggleSideCart();
}

function endBuy() {
    store.toggleSideCart();
    window.location = "/carrito";
}

const formatCurrency = (value) => {
    return new Intl.NumberFormat("es-AR", {
        minimumFractionDigits: 2,
        maximumFractionDigits: 2,
    }).format(value);
};
</script>

<style lang="scss" scoped>
@use "../../scss/variables" as vars;

.overlay {
    position: fixed;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    background: rgb(0 0 0 / 50%);
    z-index: 99;
}

.side-cart {
    position: fixed;
    top: 0;
    right: 0;
    width: 100%;
    max-width: 392px;
    height: 100%;
    background: white;
    padding: 20px;
    z-index: 100;
    box-shadow: -2px 0 5px rgb(0 0 0 / 50%);

    h3 {
        text-align: center;
        padding: 20px 0;
    }
}

.slide-enter-active,
.slide-leave-active {
    transition: transform 0.3s ease-in-out;
}

.slide-enter,
.slide-leave-to {
    transform: translateX(100%);
}

.slide-enter-from {
    transform: translateX(100%);
}

.overlay-fade-enter-active,
.overlay-fade-leave-active {
    transition: opacity 0.5s;
}

.overlay-fade-enter,
.overlay-fade-leave-to {
    opacity: 0;
}

.side-cart-title {
    font-family: "Plus Jakarta Sans", sans-serif;
    font-size: 22px;
    font-weight: 700;
    color: #000;
}

.just-button-side-cart {
    display: block;
}

.side-cart-close-side {
    cursor: pointer;
}
</style>
